package cn.wisenergy.service.app.impl;

import cn.wisenergy.common.utils.*;
import cn.wisenergy.mapper.*;
import cn.wisenergy.model.app.*;
import cn.wisenergy.service.app.UserService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * @author 86187
 * @ Description: 用户接口实现
 * @ Author     : 86187
 * @ Date       : 2021/1/6 16:11
 */
@Service
@Slf4j
public class UserServiceImpl extends ServiceImpl<UsersMapper, Users> implements UserService {

    @Autowired
    private UsersMapper usersMapper;

    @Autowired
    private RedisUtils redisUtils;

    private static final String INVITE_CODE = "1";

    @Override
    public Users getById(String userId) {
        return usersMapper.getByUserId(userId);
    }

    @Override
    public R<Integer> getById1(String userId) {

        return R.ok(usersMapper.ByUserId(userId));
    }

    @Override
    public Users getUserById(Long id) {
        return this.usersMapper.getUserById(id);
    }

    @Override
    public Users getByUserId(String userId) {

        return usersMapper.getByUserId(userId);
    }


    @Override
    public Users queryUsersByPhone(String userId) {
        //查询数据库，看看是否存在该用户
        return usersMapper.getByUserId(userId);
    }

    @Override
    public Users queryUsersByOpenId(String id) {
        return null;
    }


    @Override
    public Integer getUserIdById(String userId) {
        return null;
    }


    @Override
    public R<Boolean> setHeadImage(String userId, String headImage) {
        log.info("shop-mall[]UserServiceImpl[]setHeadImage[]input.param.userId,headImage:" + userId, headImage);
        if (StringUtils.isBlank(userId) || StringUtils.isBlank(headImage)) {
            return R.error("入参不能为空!");
        }

        //获取用户信息
        Users users = usersMapper.getByUserId(userId);
        if (null == users) {
            return R.error("用户信息不存在!");
        }

        //添加头像
        users.setHeadImage(headImage);
        int count = usersMapper.edit(users);
        if (count == 0) {
            return R.error("设置头像失败!");
        }
        return R.ok(0, true);
    }

    /**
     * 用户登出
     *
     * @param token
     * @return
     */
    @Override
    public int logout(String token) {
        int succ = 0;
        String key = RedisKeyUtils.formatKeyWithPrefix(Constants.Redis.PREFIX_TOKEN, token);
        redisUtils.delete(key);
        if (redisUtils.getValue(key) == null) {
            succ = 1;
        }
        return succ;
    }



}
